##  Introduction
You can configure advanced settings for the ServiceNow integration on the Advanced tab of the ServiceNow configuration page. Here, the configuration is represented in JSON format. Any changes made to the configuration on other tabs automatically appear on the Advanced tab.
Some settings can only be configured in the advanced configuration, such as OAuth 2.0 setup, advanced relation mapping, dot walking, and more. For detailed information, refer to the following sections.
![Advanced Tab](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2756c1f97a4410149cb3c881ebdbe2a3_LowRes.png)
Advanced Tab on the ServiceNow Configuration Page
